"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.secureSaveError = void 0;
const utilities_1 = require("../../utilities");
const error_1 = require("../../error");
/**
 * Form an error message for failres to securely save a value.
 *
 * @param solution Text that our caller can supply for a solution.
 */
function secureSaveError(solution) {
    const displayName = utilities_1.ImperativeConfig.instance.loadedConfig.productDisplayName || utilities_1.ImperativeConfig.instance.loadedConfig.name;
    let details = `Possible Solutions:\n` +
        ` 1. Reinstall ${displayName}. On Linux systems, also make sure to install the prerequisites listed in ${displayName} documentation.\n` +
        ` 2. Ensure ${displayName} can access secure credential storage. ${displayName} needs access to the OS to securely save credentials.`;
    if (solution != null) {
        details += `\n 3. ${solution}`;
    }
    return new error_1.ImperativeError({
        msg: "Unable to securely save credentials.",
        additionalDetails: details
    });
}
exports.secureSaveError = secureSaveError;
//# sourceMappingURL=ConfigUtils.js.map