/// <reference types="node" />
import { ProfileInfo } from "./ProfileInfo";
export declare class ProfileCredentials {
    private mProfileInfo;
    private mRequireKeytar?;
    private mSecured;
    constructor(mProfileInfo: ProfileInfo, mRequireKeytar?: () => NodeModule);
    /**
     * Check if secure credentials will be encrypted or stored in plain text.
     * If using team config, this will always return true. If using classic
     * profiles, this will check whether a custom CredentialManager is defined
     * in the Imperative settings.json file.
     */
    get isSecured(): boolean;
    /**
     * Initialize credential manager to be used for secure credential storage.
     * This method throws if ProfileCredentials.isSecured is false. If the
     * CredentialManagerFactory is already initialized, it is reused since it
     * is not possible to reinitialize.
     */
    loadManager(): Promise<void>;
    /**
     * Check whether a custom CredentialManager is defined in the Imperative
     * settings.json file.
     */
    private isCredentialManagerInAppSettings;
}
