import { IImperativeConfig } from "./doc/IImperativeConfig";
/**
 * Imperative-internal class to load overrides
 * You should not need to call this from your CLI.
 */
export declare class OverridesLoader {
    /**
     * Apply overrides to all applicable facilities and use our defaults where
     * an override is not provided.
     *
     * @param {IImperativeConfig} config - the current {@link Imperative#loadedConfig}
     * @param {any} packageJson - the current package.json
     */
    static load(config: IImperativeConfig, packageJson: any): Promise<void>;
    /**
     * Load the baked-in zowe CredentialManager and initialize it.
     * If we need to reinstate 3rd party overrides, delete this function and
     * rename loadCredentialManagerOld.
     *
     * @internal
     * @param {IImperativeConfig} config - the current {@link Imperative#loadedConfig}
     * @param {any} packageJson - the current package.json
     */
    static loadCredentialManager(config: IImperativeConfig, packageJson: any): Promise<void>;
    /**
     * Initialize the Credential Manager using the supplied override when provided.
     *
     * @param {IImperativeConfig} config - the current {@link Imperative#loadedConfig}
     * @param {any} packageJson - the current package.json
     */
    private static loadCredentialManagerOld;
    /**
     * After the plugins and secure credentials are loaded, rebuild the configuration with the
     * secure values
     */
    private static loadSecureConfig;
}
