"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ConfigUtils_1 = require("../../../../../config/src/ConfigUtils");
const security_1 = require("../../../../../security");
const utilities_1 = require("../../../../../utilities");
class SecureHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            // Setup the credential vault API for the config
            if (!security_1.CredentialManagerFactory.initialized) {
                throw ConfigUtils_1.secureSaveError();
            }
            // Create the config, load the secure values, and activate the desired layer
            const config = utilities_1.ImperativeConfig.instance.config;
            config.api.layers.activate(params.arguments.userConfig, params.arguments.globalConfig);
            const secureProps = config.api.secure.secureFields();
            if (secureProps.length === 0) {
                params.response.console.log("No secure properties found in your config");
                return;
            }
            // Prompt for values designated as secure
            for (const propName of secureProps) {
                const propValue = yield params.response.console.prompt(`Please enter ${propName}: `, { hideText: true });
                // Save the value in the config securely
                if (propValue) {
                    config.set(propName, propValue, { secure: true });
                }
            }
            // Write the config layer
            yield config.save(false);
        });
    }
}
exports.default = SecureHandler;
//# sourceMappingURL=secure.handler.js.map