/**
 * Protocol for daemon mode is to send headers similar to those used in HTTP.  All headers
 * must appear on the same line without a newline.  The version 1 of this protocol requires
 * that all 8 original headers be present.  The first header must always be x-zowe-daemon-headers
 * and the last must always be x-zowe-daemon-end.
 *
 * Integers are the only content passed.  For boolean header types, 0 = false, 1 = true.
 */
import { IDaemonHeaderOptions } from "./doc/IDaemonHeaderOptions";
/**
 * Class to construct headers for daemon mode protocol
 * @export
 * @class DaemonUtils
 */
export declare class DaemonUtils {
    /**
     * Header from the client to the server indicating a reply from `x-zowe-daemon-prompt`
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_REPLY = "x-zowe-daemon-reply:";
    /**
     * Header to indicate the count of total headers being sent including this header itself
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_HEADERS = "x-zowe-daemon-headers:";
    /**
     * Current version of the headers.  Version 1 = the first 8 headers.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_VERSION = "x-zowe-daemon-version:";
    /**
     * Alternate process exit code.  Default is 0.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_EXIT = "x-zowe-daemon-exit:";
    /**
     * Prompting is requested from the daemon to the client if 1 or 2, 2 indicates secure prompting.  Default is 0.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_PROMPT = "x-zowe-daemon-prompt:";
    /**
     * Unsecure prompting requested
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_PROMPT_UNSECURE = 1;
    /**
     * Secure prompting requested
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_PROMPT_SECURE = 2;
    /**
     * Content is for stdout if 1.  Default is 1.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_STDOUT = "x-zowe-daemon-stdout:";
    /**
     * Content is for stderr if 1. Default is 0.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_STDERR = "x-zowe-daemon-stderr:";
    /**
     * Content is a progress spinner
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_PROGRESS = "x-zowe-daemon-progress:";
    /**
     * Ending header.  Value does not matter.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_DAEMON_END = "x-zowe-daemon-end:";
    /**
     * Version 1 of the headers means there are 8 total.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_V1 = 1;
    /**
     * Version 1 of the headers means there are 8 total.
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_V1_LEN = 8;
    /**
     * Headers separator
     * @static
     * @memberof DaemonUtils
     */
    static readonly X_ZOWE_HEADERS_SEPARATOR = ";";
    /**
     * Build the header string with trailing newline.
     * @static
     * @param {IDaemonHeaderOptions} options
     * @returns {string}
     * @memberof DaemonUtils
     */
    static buildHeader(options: IDaemonHeaderOptions): string;
}
